--
-- AutoBarProfile
-- Copyright 2007+ Toadkiller of Proudmoore.
--
-- Categories for AutoBar
-- A Category encapsulates a list of items / spells etc. along with metadata describing their use.
-- http://code.google.com/p/autobar/
--

--	PeriodicGroup
--		description
--		texture
--		targetted
--		nonCombat
--		location
--		battleground
--		notUsable (soul shards, arrows, etc.)
--		flying

--	AutoBar
--		arrangeOnUse

--		spell
--		limit


AutoBarCategoryList = {}

local L = AceLibrary("AceLocale-2.2"):new("AutoBar")
local PT = AceLibrary:GetInstance("PeriodicTable-3.0")
local BS = AceLibrary:GetInstance("Babble-Spell-2.2")
local BZ = AceLibrary:GetInstance("Babble-Zone-2.2")
local AceOO = AceLibrary("AceOO-2.0")

-- Mandatory attributes:
--		description - localized description
--		texture - display icon texture
-- Optional attributes:
--		arrangeOnUse, targetted, nonCombat, location, battleground, notUsable
AutoBarCategory = AceOO.Class()
AutoBarCategory.virtual = true -- this means that it cannot be instantiated. (cannot call :new())

function AutoBarCategory.prototype:init(description, texture)
	AutoBarCategory.super.prototype.init(self) -- very important. Will fail without this.
	self.description = L[description]
	self.texture = texture
end

-- True if an item gets arranged to the top on use
function AutoBarCategory.prototype:SetArrangeOnUse(arrangeOnUse)
	self.arrangeOnUse = arrangeOnUse
end

-- Move item to the top (end) of list
function AutoBarCategory.prototype:ArrangeOnUse(item)
-- TODO: arrangeOnUseduivel

end

-- True if items can be targetted
function AutoBarCategory.prototype:SetTargetted(targetted)
	self.targetted = targetted
end

-- True if only usable outside combat
function AutoBarCategory.prototype:SetNonCombat(nonCombat)
	self.nonCombat = nonCombat
end

-- True if item is location specific
function AutoBarCategory.prototype:SetLocation(location)
	self.location = location
end

-- True if item is for battlegrounds only
function AutoBarCategory.prototype:SetBattleground(battleground)
	self.battleground = battleground
end

-- True if item is not usable (soul shards, arrows, etc.)
function AutoBarCategory.prototype:SetNotUsable(notUsable)
	self.notUsable = notUsable
end

-- Called once to allocate space and initialize items
function AutoBarCategory.prototype:ItemsInit()
	self.items = nil
end

-- Reset the item list based on changed settings.
-- So pet change, Spellbook changed for spells, etc.
function AutoBarCategory.prototype:ItemsRefresh()
end



-- Category consisting of regular items
AutoBarItems = AceOO.Class(AutoBarCategory)

-- Add a list of itemIds for the given buttonsIndex
-- ptItems, ptPriorityItems are lists of PeriodicTable nodes
-- priorityItems sort higher than items at the same value
function AutoBarItems.prototype:init(description, texture, ptItems, ptPriorityItems)
	AutoBarItems.super.prototype.init(self, description, texture) -- very important. Will fail without this.
	self.ptItems = ptItems
	self.ptPriorityItems = ptPriorityItems

	local rawList = nil
	rawList = AutoBarCategoryList:RawItemsAdd(rawList, ptItems, false)
	if (ptPriorityItems) then
		rawList = AutoBarCategoryList:RawItemsAdd(rawList, ptPriorityItems, true)
	end
	self.items = AutoBarCategoryList:RawItemsConvert(rawList)
end

-- Reset the item list based on changed settings.
function AutoBarItems.prototype:ItemsRefresh()
end












local function sortList(a, b)
	local x = tonumber(a[2]);
	local y = tonumber(b[2]);

	if (x == y) then
		if (a[3]) then
			return false;
		else
			if (b[3]) then
				return true;
			else
				return false;
			end
		end
	else
		return x < y;
	end
end


-- Get set as a simple array of itemIds, ordered by their value in the set
-- If provided, also record the values scaled by downFactor into downHp, downMana
function AutoBarCategoryList:GetSetItemsArrayPT3(set, downHp, downMana, downFactor)
	local itemArray = {};
	local cacheSet = PT:GetSetTable(set);
	if (cacheSet) then
		local sortedList = {};
		local index = 1;
		for itemId, value in PT:IterateSet(set) do
			if (type(value) == "boolean") then
				value = 0;
			end
			sortedList[index] = { itemId, value };
			index = index + 1;
		end
		table.sort(sortedList, sortList);
		for i, j in ipairs(sortedList) do
			itemArray[i] = j[1];
			if (downHp) then
				downHp[i] = j[2] * downFactor;
			end
			if (downMana) then
				downMana[i] = j[2]* downFactor;
			end
		end
	end
	return itemArray;
end


-- Convert rawList to a simple array of itemIds, ordered by their value in the set, and priority if any
-- If provided, also record the values scaled by downFactor into downHp, downMana
function AutoBarCategoryList:RawItemsConvert(rawList, downHp, downMana, downFactor)
	local itemArray = {};
	table.sort(rawList, sortList);
	for i, j in ipairs(rawList) do
		itemArray[i] = j[1];
		if (downHp) then
			downHp[i] = j[2] * downFactor;
		end
		if (downMana) then
			downMana[i] = j[2]* downFactor;
		end
	end
	return itemArray;
end


-- Add items from set to rawList
-- If priority is true, the items will have priority over non-priority items with the same values
function AutoBarCategoryList:RawItemsAdd(rawList, set, priority)
--DEFAULT_CHAT_FRAME:AddMessage("RawItemsAdd set " .. tostring(set).." priority ".. tostring(priority));
	if (not rawList) then
		rawList = {};
	end
	local cacheSet = PT:GetSetTable(set);
	if (cacheSet) then
		local index = table.getn(rawList) + 1;
		for itemId, value in PT:IterateSet(set) do
			if (not value or type(value) == "boolean") then
				value = 0;
			end
			value = tonumber(value);
			rawList[index] = {itemId, value, priority};
			index = index + 1;
		end
	end
	return rawList;
end


-- Fill in category item lists with the raw data from PeriodicTable.
-- Unless AutoBar is drastically restructured thats the most use we can get from PeriodicTable
function AutoBarCategoryList:Initialize()
--	AutoBar_Category_Info["ANTI_VENOM"]["items"] = self:GetSetItemsArrayPT3("Consumable.Anti-Venom");
--	AutoBar_Category_Info["ARROWS"]["items"] = self:GetSetItemsArrayPT3("Reagent.Ammo.Arrow");
--	AutoBar_Category_Info["BULLETS"]["items"] = self:GetSetItemsArrayPT3("Reagent.Ammo.Bullet");
--	AutoBar_Category_Info["THROWN"]["items"] = self:GetSetItemsArrayPT3("Reagent.Ammo.Thrown");
--	AutoBar_Category_Info["BANDAGES"]["items"] = self:GetSetItemsArrayPT3("Consumable.Bandage.Basic");
--	AutoBar_Category_Info["ALTERAC_BANDAGES"]["items"] = self:GetSetItemsArrayPT3("Consumable.Bandage.Battleground.Alterac Valley");
--	AutoBar_Category_Info["ARATHI_BANDAGES"]["items"] = self:GetSetItemsArrayPT3("Consumable.Bandage.Battleground.Arathi Basin");
--	AutoBar_Category_Info["WARSONG_BANDAGES"]["items"] = self:GetSetItemsArrayPT3("Consumable.Bandage.Battleground.Warsong Gulch");
--	AutoBar_Category_Info["EXPLOSIVES"]["items"] = self:GetSetItemsArrayPT3("Misc.Engineering.Explosives");
--	AutoBar_Category_Info["FISHING_GEAR"]["items"] = self:GetSetItemsArrayPT3("Tradeskill.Tool.Fishing.Gear");
--	AutoBar_Category_Info["FISHING_LURES"]["items"] = self:GetSetItemsArrayPT3("Tradeskill.Tool.Fishing.Lure");
--	AutoBar_Category_Info["FISHING_POLES"]["items"] = self:GetSetItemsArrayPT3("Tradeskill.Tool.Fishing.Tool");
--	AutoBar_Category_Info["FOOD"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Edible.Basic.Non-Conjured");
--	AutoBar_Category_Info["FOOD_ARATHI"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Edible.Battleground.Arathi Basin.Basic");
--	AutoBar_Category_Info["FOOD_WARSONG"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Edible.Battleground.Warsong Gulch.Basic");
--	AutoBar_Category_Info["FOOD_COMBO"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Combo Health");
--	AutoBar_Category_Info["FOOD_CONJURED"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Edible.Bread.Conjured");
--	AutoBar_Category_Info["FOOD_PERCENT"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Percent.Basic");
--	AutoBar_Category_Info["FOOD_PERCENT_BONUS"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Percent.Bonus");
--	AutoBar_Category_Info["FOOD_PERCENT_COMBO"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Combo Percent");
--
--	rawList = self:RawItemsAdd(nil, "Consumable.Food.Edible.Bread.Basic", false);
--	rawList = self:RawItemsAdd(rawList, "Consumable.Food.Edible.Bread.Conjured", true);
--	AutoBar_Category_Info["FOOD_PET_BREAD"]["items"] = self:RawItemsConvert(rawList);
--
--	AutoBar_Category_Info["FOOD_PET_CHEESE"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Edible.Cheese.Basic");
--
--	rawList = self:RawItemsAdd(nil, "Consumable.Food.Inedible.Fish", false);
--	rawList = self:RawItemsAdd(rawList, "Consumable.Food.Edible.Fish.Basic", true);
--	AutoBar_Category_Info["FOOD_PET_FISH"]["items"] = self:RawItemsConvert(rawList);
--
--	AutoBar_Category_Info["FOOD_PET_FRUIT"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Edible.Fruit.Basic");
--	AutoBar_Category_Info["FOOD_PET_FUNGUS"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Edible.Fungus.Basic");	-- Now includes senjin combo ;-(
--
--	rawList = self:RawItemsAdd(nil, "Consumable.Food.Inedible.Meat", false);
--	rawList = self:RawItemsAdd(rawList, "Consumable.Food.Edible.Meat.Basic", true);
--	AutoBar_Category_Info["FOOD_PET_MEAT"]["items"] = self:RawItemsConvert(rawList);
--
--	AutoBar_Category_Info["FOOD_BUFF"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Bonus");
--
--	AutoBar_Category_Info["FOOD_AGILITY"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Agility");
--	AutoBar_Category_Info["FOOD_ATTACK_POWER"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Attack Power");
--	AutoBar_Category_Info["FOOD_HEALING"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Healing");
--	AutoBar_Category_Info["FOOD_HPREGEN"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.HP Regen");
--	AutoBar_Category_Info["FOOD_INTELLECT"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Intellect");
--	AutoBar_Category_Info["FOOD_MANAREGEN"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Mana Regen");
--	AutoBar_Category_Info["FOOD_STAMINA"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Stamina");
--	AutoBar_Category_Info["FOOD_SPELL_DAMAGE"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Spell Damage");
--	AutoBar_Category_Info["FOOD_SPIRIT"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Spirit");
--	AutoBar_Category_Info["FOOD_STRENGTH"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Strength");
--
--	AutoBar_Category_Info["FOOD_OTHER"]["items"] = self:GetSetItemsArrayPT3("Consumable.Food.Buff.Other");
--
	AutoBar_Category_Info["HEALPOTIONS"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Healing.Basic", "INV_Potion_54", "Consumable.Potion.Recovery.Healing.Basic")

	AutoBar_Category_Info["HEALPOTIONS_BG"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Healing.PvP", "INV_Potion_39", "Consumable.Potion.Recovery.Healing.PvP")
	AutoBar_Category_Info["HEALPOTIONS_BG"]:SetBattleground(true)

	AutoBar_Category_Info["Consumable.Potion.Recovery.Healing.Blades Edge"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Healing.Blades Edge", "INV_Potion_167", "Consumable.Potion.Recovery.Healing.Blades Edge")
	AutoBar_Category_Info["Consumable.Potion.Recovery.Healing.Blades Edge"]:SetLocation(BZ["Blade's Edge Mountains"])

	AutoBar_Category_Info["Consumable.Potion.Recovery.Healing.Coilfang"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Healing.Coilfang", "INV_Potion_167", "Consumable.Potion.Recovery.Healing.Coilfang")
	AutoBar_Category_Info["Consumable.Potion.Recovery.Healing.Coilfang"]:SetLocation("Coilfang")

	AutoBar_Category_Info["Consumable.Potion.Recovery.Healing.Tempest Keep"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Healing.Tempest Keep", "INV_Potion_153", "Consumable.Potion.Recovery.Healing.Tempest Keep")
	AutoBar_Category_Info["Consumable.Potion.Recovery.Healing.Tempest Keep"]:SetLocation("Tempest Keep")

	AutoBar_Category_Info["MANAPOTIONS"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Mana.Basic", "INV_Potion_76", "Consumable.Potion.Recovery.Mana.Basic")

	AutoBar_Category_Info["MANAPOTIONS_BG"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Mana.Pvp", "INV_Potion_81", "Consumable.Potion.Recovery.Mana.Pvp")
	AutoBar_Category_Info["MANAPOTIONS_BG"]:SetBattleground(true)

	AutoBar_Category_Info["Consumable.Potion.Recovery.Mana.Blades Edge"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Mana.Blades Edge", "INV_Potion_168", "Consumable.Potion.Recovery.Mana.Blades Edge")
	AutoBar_Category_Info["Consumable.Potion.Recovery.Mana.Blades Edge"]:SetLocation(BZ["Blade's Edge Mountains"])

	AutoBar_Category_Info["Consumable.Potion.Recovery.Mana.Coilfang"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Mana.Coilfang", "INV_Potion_168", "Consumable.Potion.Recovery.Mana.Coilfang")
	AutoBar_Category_Info["Consumable.Potion.Recovery.Mana.Coilfang"]:SetLocation("Coilfang")

	AutoBar_Category_Info["Consumable.Potion.Recovery.Mana.Tempest Keep"] = AutoBarItems:new(
			"Consumable.Potion.Recovery.Mana.Tempest Keep", "INV_Potion_156", "Consumable.Potion.Recovery.Mana.Tempest Keep")
	AutoBar_Category_Info["Consumable.Potion.Recovery.Mana.Tempest Keep"]:SetLocation("Tempest Keep")

--	AutoBar_Category_Info["HEALTHSTONE"]["items"] = self:GetSetItemsArrayPT3("Consumable.Warlock.Healthstone");
--	["HEALTHSTONE"] = {
--		["description"] = AUTOBAR_CLASS_HEALTHSTONE;
--		["texture"] = "INV_Stone_04";
--	},
--	AutoBar_Category_Info["MINI_PET"]["items"] = self:GetSetItemsArrayPT3("Misc.Minipet.Normal");
--	AutoBar_Category_Info["MINI_PET_HOLIDAY"]["items"] = self:GetSetItemsArrayPT3("Misc.Minipet.Snowball");
--	["MINI_PET"] = {
--		["description"] = AUTOBAR_CLASS_MINI_PET;
--		["texture"] = "Ability_Creature_Poison_05";
--		["arrangeOnUse"] = true,
--	},
--	["MINI_PET_HOLIDAY"] = {
--		["description"] = AUTOBAR_CLASS_MINI_PET_HOLIDAY;
--		["texture"] = "INV_Misc_Bag_17";
--		["arrangeOnUse"] = true,
--	},

--	AutoBar_Category_Info["MOUNTS"]["items"] = self:GetSetItemsArrayPT3("Misc.Mount.Normal");
--	AutoBar_Category_Info["MOUNTS_QIRAJI"]["items"] = self:GetSetItemsArrayPT3("Misc.Mount.Ahn'Qiraj");
--	AutoBar_Category_Info["MOUNTS_FLYING"]["items"] = self:GetSetItemsArrayPT3("Misc.Mount.Flying");
--	["MOUNTS"] = {
--		["description"] = AUTOBAR_CLASS_MOUNTS;
--		["texture"] = "Ability_Mount_JungleTiger";
--		["nonCombat"] = true,
--		["arrangeOnUse"] = true,
--	},
--	["MOUNTS_QIRAJI"] = {
--		["description"] = AUTOBAR_CLASS_MOUNTS_QIRAJI;
--		["texture"] = "INV_Misc_QirajiCrystal_05";
--		["nonCombat"] = true,
--		["arrangeOnUse"] = true,
--		["location"] = AUTOBAR_AHN_QIRAJ;
--	},
--	["MOUNTS_FLYING"] = {
--		["description"] = AUTOBAR_CLASS_MOUNTS_FLYING;
--		["texture"] = "Ability_Mount_Wyvern_01";
--		["nonCombat"] = true,
--		["arrangeOnUse"] = true,
----		["location"] = AUTOBAR_OUTLAND;  TODO: can fly check
--	},

--	AutoBar_Category_Info["REJUVENATION_POTIONS"]["limit"] = { ["downhp"] = {}, ["downmana"] = {},  }
--	AutoBar_Category_Info["REJUVENATION_POTIONS"]["items"] = self:GetSetItemsArrayPT3("Consumable.Potion.Recovery.Rejuvenation",
--			AutoBar_Category_Info["REJUVENATION_POTIONS"]["limit"]["downhp"],
--			AutoBar_Category_Info["REJUVENATION_POTIONS"]["limit"]["downmana"],
--			1.1);
--	["REJUVENATION_POTIONS"] = {
--		["description"] = AUTOBAR_CLASS_REJUVENATION_POTIONS;
--		["texture"] = "INV_Potion_47";
--	},

--	AutoBar_Category_Info["STONE_STATUES"]["items"] = self:GetSetItemsArrayPT3("Consumable.Jeweler.Statue");
--	["STONE_STATUES"] = {
--		["description"] = AUTOBAR_CLASS_STONE_STATUES;
--		["texture"] = "INV_Misc_Statue_10";
--	},

--	AutoBar_Category_Info["DREAMLESS_SLEEP"]["items"] = self:GetSetItemsArrayPT3("Consumable.Potion.Recovery.Dreamless Sleep");
--	["DREAMLESS_SLEEP"] = {
--		["description"] = AUTOBAR_CLASS_DREAMLESS_SLEEP;
--		["texture"] = "INV_Potion_83";
--	},

--	AutoBar_Category_Info["MANASTONE"]["items"] = self:GetSetItemsArrayPT3("Consumable.Mage.Mana Stone");
--	["MANASTONE"] = {
--		["description"] = AUTOBAR_CLASS_MANASTONE;
--		["texture"] = "INV_Misc_Gem_Emerald_01";
--	},

--	AutoBar_Category_Info["RAGEPOTIONS"]["items"] = self:GetSetItemsArrayPT3("Consumable.Buff.Rage.Self");
--	["RAGEPOTIONS"] = {
--		["description"] = AUTOBAR_CLASS_RAGEPOTIONS;
--		["texture"] = "INV_Potion_24";
--	},

--	["ENERGYPOTIONS"] = {
--		["description"] = AUTOBAR_CLASS_ENERGYPOTIONS;
--		["texture"] = "INV_Drink_Milk_05";
--		["items"] = { 7676 },
--	},

--	rawList = self:RawItemsAdd(nil, "Consumable.Water.Basic", false);
--	rawList = self:RawItemsAdd(rawList, "Consumable.Water.Conjured", true);
--	AutoBar_Category_Info["WATER"]["items"] = self:RawItemsConvert(rawList);
--	["WATER"] = {
--		["description"] = AUTOBAR_CLASS_WATER;
--		["texture"] = "INV_Drink_10";
--		["nonCombat"] = true,
--		["castList"] = {"MAGE", BS["Conjure Water"],},
--	},

--	AutoBar_Category_Info["WATER_SPIRIT"]["items"] = self:GetSetItemsArrayPT3("Consumable.Water.Buff.Spirit");
--	["WATER_SPIRIT"] = {
--		["description"] = AUTOBAR_CLASS_WATER_SPIRIT;
--		["texture"] = "INV_Drink_16";
--		["nonCombat"] = true,
--	},


	AutoBar_Category_Info["OIL_MANA"] = AutoBarItems:new("Consumable.Weapon Buff.Oil.Mana", "INV_Potion_100",
			"Consumable.Weapon Buff.Oil.Mana")
	AutoBar_Category_Info["OIL_MANA"]:SetTargetted("WEAPON")

	AutoBar_Category_Info["OIL_WIZARD"] = AutoBarItems:new("Consumable.Weapon Buff.Oil.Wizard", "INV_Potion_105",
			"Consumable.Weapon Buff.Oil.Wizard")
	AutoBar_Category_Info["OIL_WIZARD"]:SetTargetted("WEAPON")

	AutoBar_Category_Info["POISON-CRIPPLING"] = AutoBarItems:new("Consumable.Weapon Buff.Poison.Crippling", "INV_Potion_19",
			"Consumable.Weapon Buff.Poison.Crippling")
	AutoBar_Category_Info["POISON-CRIPPLING"]:SetTargetted("WEAPON")

	AutoBar_Category_Info["POISON-DEADLY"] = AutoBarItems:new("Consumable.Weapon Buff.Poison.Deadly", "Ability_Rogue_DualWeild",
			"Consumable.Weapon Buff.Poison.Deadly")
	AutoBar_Category_Info["POISON-DEADLY"]:SetTargetted("WEAPON")

	AutoBar_Category_Info["POISON-INSTANT"] = AutoBarItems:new("Consumable.Weapon Buff.Poison.Instant", "Ability_Poisons",
			"Consumable.Weapon Buff.Poison.Instant", "Consumable.Weapon Buff.Poison.Anesthetic")
	AutoBar_Category_Info["POISON-INSTANT"]:SetTargetted("WEAPON")

	AutoBar_Category_Info["POISON-MINDNUMBING"] = AutoBarItems:new("Consumable.Weapon Buff.Poison.Mind Numbing", "Spell_Nature_NullifyDisease",
			"Consumable.Weapon Buff.Poison.Mind Numbing")
	AutoBar_Category_Info["POISON-MINDNUMBING"]:SetTargetted("WEAPON")

	AutoBar_Category_Info["POISON-WOUND"] = AutoBarItems:new("Consumable.Weapon Buff.Poison.Wound", "Ability_PoisonSting",
			"Consumable.Weapon Buff.Poison.Wound")
	AutoBar_Category_Info["POISON-WOUND"]:SetTargetted("WEAPON")

	AutoBar_Category_Info["SHARPENINGSTONES"] = AutoBarItems:new("Consumable.Weapon Buff.Stone.Sharpening Stone", "INV_Stone_SharpeningStone_01",
			"Consumable.Weapon Buff.Stone.Sharpening Stone")
	AutoBar_Category_Info["SHARPENINGSTONES"]:SetTargetted("WEAPON")

	AutoBar_Category_Info["WEIGHTSTONES"] = AutoBarItems:new("Consumable.Weapon Buff.Stone.Weight Stone", "INV_Stone_WeightStone_02",
			"Consumable.Weapon Buff.Stone.Weight Stone")
	AutoBar_Category_Info["WEIGHTSTONES"]:SetTargetted("WEAPON")


	AutoBar_Category_Info["BUFF_GENERAL"] = AutoBarItems:new("Consumable.Buff Group.General.Self", "INV_Potion_80",
			"Consumable.Buff Group.General.Self")
	AutoBar_Category_Info["BUFF_GENERAL_TARGET"] = AutoBarItems:new("Consumable.Buff Group.General.Target", "INV_Potion_80",
			"Consumable.Buff Group.General.Target")
	AutoBar_Category_Info["BUFF_GENERAL_TARGET"]:SetTargetted(true)

	AutoBar_Category_Info["BUFF_CASTER"] = AutoBarItems:new("Consumable.Buff Group.Caster.Self", "INV_Potion_66",
			"Consumable.Buff Group.Caster.Self")
	AutoBar_Category_Info["BUFF_CASTER_TARGET"] = AutoBarItems:new("Consumable.Buff Group.Caster.Target", "INV_Potion_66",
			"Consumable.Buff Group.Caster.Target")
	AutoBar_Category_Info["BUFF_CASTER_TARGET"]:SetTargetted(true)

	AutoBar_Category_Info["BUFF_MELEE"] = AutoBarItems:new("Consumable.Buff Group.Melee.Self", "INV_Potion_43",
			"Consumable.Buff Group.Melee.Self")
	AutoBar_Category_Info["BUFF_MELEE_TARGET"] = AutoBarItems:new("Consumable.Buff Group.Melee.Target", "INV_Potion_43",
			"Consumable.Buff Group.Melee.Target")
	AutoBar_Category_Info["BUFF_MELEE_TARGET"]:SetTargetted(true)

	AutoBar_Category_Info["BUFF_OTHER"] = AutoBarItems:new("Consumable.Buff.Other.Self", "INV_Potion_80",
			"Consumable.Buff.Other.Self")
	AutoBar_Category_Info["BUFF_OTHER_TARGET"] = AutoBarItems:new("Consumable.Buff.Other.Target", "INV_Potion_80",
			"Consumable.Buff.Other.Target")
	AutoBar_Category_Info["BUFF_OTHER_TARGET"]:SetTargetted(true)

	AutoBar_Category_Info["BUFF_CHEST"] = AutoBarItems:new("Consumable.Buff.Chest", "INV_Misc_Rune_10",
			"Consumable.Buff.Chest")
	AutoBar_Category_Info["BUFF_CHEST"]:SetTargetted("CHEST")
	AutoBar_Category_Info["BUFF_SHIELD"] = AutoBarItems:new("Consumable.Buff.Shield", "INV_Misc_Rune_13",
			"Consumable.Buff.Shield")
	AutoBar_Category_Info["BUFF_SHIELD"]:SetTargetted("SHIELD")
	AutoBar_Category_Info["BUFF_WEAPON"] = AutoBarItems:new("Consumable.Weapon Buff", "INV_Misc_Rune_13",
			"Consumable.Weapon Buff")
	AutoBar_Category_Info["BUFF_WEAPON"]:SetTargetted("WEAPON")

	AutoBar_Category_Info["BUFF_HEALTH"] = AutoBarItems:new("Consumable.Buff.Health", "INV_Potion_43",
			"Consumable.Buff.Health")
	AutoBar_Category_Info["BUFF_ARMOR"] = AutoBarItems:new("Consumable.Buff.Armor", "INV_Potion_66",
			"Consumable.Buff.Armor")
	AutoBar_Category_Info["BUFF_REGENHEALTH"] = AutoBarItems:new("Consumable.Buff.Regen Health", "INV_Potion_80",
			"Consumable.Buff.Regen Health")
	AutoBar_Category_Info["BUFF_AGILITY"] = AutoBarItems:new("Consumable.Buff.Agility", "INV_Scroll_02",
			"Consumable.Buff.Agility")
	AutoBar_Category_Info["BUFF_AGILITY"]:SetTargetted(true)
	AutoBar_Category_Info["BUFF_INTELLECT"] = AutoBarItems:new("Consumable.Buff.Intellect", "INV_Scroll_01",
			"Consumable.Buff.Intellect")
	AutoBar_Category_Info["BUFF_INTELLECT"]:SetTargetted(true)
--	AutoBar_Category_Info["BUFF_PROTECTION"] = AutoBarItems:new("Consumable.Buff.Protection", "INV_Scroll_07",
--			"Consumable.Buff.Protection")
--	AutoBar_Category_Info["BUFF_PROTECTION"]:SetTargetted(true)
	AutoBar_Category_Info["BUFF_SPIRIT"] = AutoBarItems:new("Consumable.Buff.Spirit", "INV_Scroll_01",
			"Consumable.Buff.Spirit")
	AutoBar_Category_Info["BUFF_SPIRIT"]:SetTargetted(true)
	AutoBar_Category_Info["BUFF_STAMINA"] = AutoBarItems:new("Consumable.Buff.Stamina", "INV_Scroll_07",
			"Consumable.Buff.Stamina")
	AutoBar_Category_Info["BUFF_STAMINA"]:SetTargetted(true)
	AutoBar_Category_Info["BUFF_STRENGTH"] = AutoBarItems:new("Consumable.Buff.Strength", "INV_Scroll_02",
			"Consumable.Buff.Strength")
	AutoBar_Category_Info["BUFF_STRENGTH"]:SetTargetted(true)
	AutoBar_Category_Info["BUFF_ATTACKPOWER"] = AutoBarItems:new("Consumable.Buff.Attack Power", "INV_Misc_MonsterScales_07",
			"Consumable.Buff.Attack Power")
	AutoBar_Category_Info["BUFF_ATTACKPOWER"]:SetTargetted(true)
	AutoBar_Category_Info["BUFF_ATTACKSPEED"] = AutoBarItems:new("Consumable.Buff.Attack Speed", "INV_Misc_MonsterScales_17",
			"Consumable.Buff.Attack Speed")
	AutoBar_Category_Info["BUFF_ATTACKSPEED"]:SetTargetted(true)
	AutoBar_Category_Info["BUFF_DODGE"] = AutoBarItems:new("Consumable.Buff.Dodge", "INV_Misc_MonsterScales_17",
			"Consumable.Buff.Dodge")
	AutoBar_Category_Info["BUFF_DODGE"]:SetTargetted(true)
	AutoBar_Category_Info["BUFF_RESISTANCE"] = AutoBarItems:new("Consumable.Buff.Resistance", "INV_Misc_MonsterScales_15",
			"Consumable.Buff.Resistance.Self")
	AutoBar_Category_Info["BUFF_RESISTANCE_TARGET"] = AutoBarItems:new("Consumable.Buff.Resistance", "INV_Misc_MonsterScales_15",
			"Consumable.Buff.Resistance.Target")
	AutoBar_Category_Info["BUFF_RESISTANCE_TARGET"]:SetTargetted(true)
	AutoBar_Category_Info["QUEST_ITEMS"] = AutoBarItems:new("Consumable.Quest.Usable", "INV_BannerPVP_02",
			"Consumable.Quest.Usable")
	AutoBar_Category_Info["QUEST_ITEMS"]:SetArrangeOnUse(true)
end



--AutoBar_Category_Info = {
--	["CUSTOM"] = {
--		["description"] = AUTOBAR_CLASS_CUSTOM;
--		["texture"] = "INV_Misc_Bandage_12",
--		["custom"] = true;
--		["items"] = { 19307 },
--	},
--	["Fireworks"] = {
--		["description"] = L["Fireworks"];
--		["texture"] = "INV_Misc_MissileSmall_Red";
--		["arrangeOnUse"] = true,
--	},
--	["AAACLEAR"] = {
--		["description"] = AUTOBAR_CLASS_CLEAR;
--		["texture"] = "INV_Misc_Fork&Knife";
--		["items"] = {},
--	},
--	["BANDAGES"] = {
--		["description"] = AUTOBAR_CLASS_BANDAGES;
--		["texture"] = "INV_Misc_Bandage_Netherweave_Heavy";
--		["targetted"] = true;
--	},
--	["ALTERAC_BANDAGES"] = {
--		["description"] = AUTOBAR_CLASS_ALTERAC_BANDAGE;
--		["texture"] = "INV_Misc_Bandage_12";
--		["targetted"] = true;
--		["location"] = AUTOBAR_ALTERACVALLEY;
--	},
--	["WARSONG_BANDAGES"] = {
--		["description"] = AUTOBAR_CLASS_WARSONG_BANDAGE;
--		["texture"] = "INV_Misc_Bandage_12";
--		["targetted"] = true;
--		["location"] = AUTOBAR_WARSONGGULCH;
--	},
--	["ARATHI_BANDAGES"] = {
--		["description"] = AUTOBAR_CLASS_ARATHI_BANDAGE;
--		["texture"] = "INV_Misc_Bandage_12";
--		["targetted"] = true;
--		["location"] = AUTOBAR_ARATHIBASIN;
--	},
--	["UNGORO_RESTORE"] = {
--		["description"] = AUTOBAR_CLASS_UNGORORESTORE;
--		["texture"] = "INV_Misc_Gem_Diamond_02";
--		["targetted"] = true;
--		["limit"] = { ["downhp"] = { 670 } },
--		["items"] = { 11562 },
--	},
--	["ANTI_VENOM"] = {
--		["description"] = AUTOBAR_CLASS_ANTIVENOM;
--		["texture"] = "INV_Drink_14";
--		["targetted"] = true;
--	},
--	----------------
--	["FISHING_LURES"] = {
--		["texture"] = "INV_Misc_Food_26",
--		["targetted"] = "WEAPON",
--		["description"] = L["FISHING_LURES"],
--	},
--	["FISHING_GEAR"] = {
--		["texture"] = "INV_Helmet_31",
--		["description"] = L["FISHING_GEAR"],
--	},
--	["FISHING_POLES"] = {
--		["texture"] = "INV_Fishingpole_01",
--		["description"] = L["FISHING_POLES"],
--	},
--	----------------
--	["HEALTHSTONE_CONJURE"] = {
--		["description"] = AUTOBAR_CLASS_HEALTHSTONE_CONJURE,
--		["texture"] = BS:GetShortSpellIcon("Create Healthstone"),
--		["spell"] = true,
--		["castList"] = {"WARLOCK", BS["Create Healthstone"]};
--	},
--	["WHIPPER_ROOT"] = {
--		["description"] = AUTOBAR_CLASS_WHIPPER_ROOT;
--		["texture"] = "INV_Misc_Food_55";
--		["items"] = { 11951 },
--		["limit"] = { ["downhp"] = { 700 } },
--	},
--	----------------
--	["MANASTONE_CONJURE"] = {
--		["description"] = AUTOBAR_CLASS_MANASTONE_CONJURE;
--		["texture"] = "INV_Misc_Gem_Emerald_01";
--	},
--	["NIGHT_DRAGONS_BREATH"] = {
--		["description"] = AUTOBAR_CLASS_NIGHT_DRAGONS_BREATH;
--		["texture"] = "INV_Misc_Food_45";
--		["limit"] = { ["downhp"] = { 456 }, ["downmana"] = { 456 }, },
--		["items"] = { 11952 },
--	},
--	----------------
--	["BATTLE_STANDARD"] = {
--		["description"] = AUTOBAR_CLASS_BATTLESTANDARD;
--		["texture"] = "INV_BannerPVP_01";
--		["battleground"] = true;
--		["items"] = {
--			18606,	-- Alliance Battle Standard
--			18607,	-- Horde Battle Standard
--		},
--	},
--	["BATTLE_STANDARD_AV"] = {
--		["description"] = AUTOBAR_CLASS_BATTLESTANDARDAV;
--		["texture"] = "INV_BannerPVP_02";
--		["location"] = AUTOBAR_ALTERACVALLEY;
--		["items"] = {
--			19045,	-- Stormpike Battle Standard
--			19046,	-- Frostwolf Battle Standard
--		},
--	},
--	["HOURGLASS_SAND"] = {
--		["description"] = AUTOBAR_CLASS_BATTLESTANDARDAV;
--		["texture"] = "INV_BannerPVP_02";
--		["location"] = AUTOBAR_BWL;
--		["items"] = {
--			19183,	-- Hourglass Sand
--		},
--	},
--	----------------
--	["RUNES"] = {
--		["description"] = AUTOBAR_CLASS_DEMONIC_DARK_RUNES;
--		["texture"] = "Spell_Shadow_SealOfKings";
--		["limit"] = { ["downmana"] = { 900, 900 }, },
--		["items"] = {
--			20520,	-- Dark Rune
--			12662,	-- Demonic Rune
--		},
--	},
--	----------------
--	["PROTECTION_ARCANE"] = {
--		["description"] = AUTOBAR_CLASS_ARCANE_PROTECTION;
--		["texture"] = "INV_Potion_83";
--		["items"] = { 13461 },
--	},
--	["PROTECTION_FIRE"] = {
--		["description"] = AUTOBAR_CLASS_FIRE_PROTECTION;
--		["texture"] = "INV_Potion_24";
--		["items"] = { 6049, 13457 },
--	},
--	["PROTECTION_FROST"] = {
--		["description"] = AUTOBAR_CLASS_FROST_PROTECTION;
--		["texture"] = "INV_Potion_20";
--		["items"] = { 6050, 13456 },
--	},
--	["PROTECTION_NATURE"] = {
--		["description"] = AUTOBAR_CLASS_NATURE_PROTECTION;
--		["texture"] = "INV_Potion_22";
--		["items"] = { 6052, 13458 },
--	},
--	["PROTECTION_SHADOW"] = {
--		["description"] = AUTOBAR_CLASS_SHADOW_PROTECTION;
--		["texture"] = "INV_Potion_23";
--		["items"] = { 6048, 13459 },
--	},
--	["PROTECTION_SPELLS"] = {
--		["description"] = AUTOBAR_CLASS_SPELL_PROTECTION;
--		["texture"] = "INV_Potion_29";
--		["items"] = {
--			20080	-- Sheen of Zanza
--		},
--	},
--	["PROTECTION_HOLY"] = {
--		["description"] = AUTOBAR_CLASS_HOLY_PROTECTION;
--		["texture"] = "INV_Potion_09";
--		["items"] = { 6051 },
--		["nonCombat"] = false,
--	},
--	["PROTECTION_DAMAGE"] = {
--		["description"] = AUTOBAR_CLASS_INVULNERABILITY_POTIONS;
--		["texture"] = "INV_Potion_62";
--		["items"] = { 3387 },
--		["nonCombat"] = false,
--	},
--	["ACTION_POTIONS"] = {
--		["description"] = AUTOBAR_CLASS_FREE_ACTION_POTION;
--		["texture"] = "INV_Potion_04";
--		["items"] = {
--			20008,		-- Living Action Potion
--			5634,		-- Free Action Potion
--		},
--	},
--	----------------
--	["HEARTHSTONE"] = {
--		["description"] = AUTOBAR_CLASS_HEARTHSTONE;
--		["texture"] = "INV_Misc_Rune_01";
--		["items"] = {
--			6948,			-- HearthStone
--		},
--	},
--	["PORTALS"] = {
--		["description"] = AUTOBAR_CLASS_PORTALS;
--		["texture"] = "Spell_Arcane_PortalShattrath";
--		["spell"] = true,
--	},
--	----------------
--	["BOOZE"] = {
--		["description"] = AUTOBAR_CLASS_BOOZE;
--		["texture"] = "INV_Drink_03";
--		["nonCombat"] = true,
--	},
--	["WATER_PERCENT"] = {
--		["description"] = AUTOBAR_CLASS_WATER_PERCENT;
--		["texture"] = "INV_Drink_04";
--		["nonCombat"] = true,
--	},
--	["WATER_CONJURED"] = {
--		["description"] = AUTOBAR_CLASS_WATER_CONJURED,
--		["texture"] = "INV_Drink_18",
--		["nonCombat"] = true,
--	},
--	["WATER_CONJURE"] = {
--		["description"] = AUTOBAR_CLASS_WATER_CONJURE,
--		["texture"] = BS:GetShortSpellIcon("Conjure Water"),
--		["spell"] = true,
--	},
--	["SWIFTNESSPOTIONS"] = {
--		["description"] = AUTOBAR_CLASS_SWIFTNESSPOTIONS;
--		["texture"] = "INV_Potion_95";
--		["items"] = { 20081, 2459, },
--	},
--	["SOULSHARDS"] = {
--		["description"] = AUTOBAR_CLASS_SOULSHARDS;
--		["texture"] = "INV_Misc_Gem_Amethyst_02";
--		["notUsable"] = true;
--		["items"] = { 6265 },
--	},
--	--------------
--	["ARROWS"] = {
--		["description"] = AUTOBAR_CLASS_ARROWS;
--		["texture"] = "INV_Ammo_Arrow_02";
--		["notUsable"] = true;
--	},
--	["BULLETS"] = {
--		["description"] = AUTOBAR_CLASS_BULLETS;
--		["texture"] = "INV_Ammo_Bullet_02";
--		["notUsable"] = true;
--	},
--	["THROWN"] = {
--		["description"] = AUTOBAR_CLASS_THROWNWEAPON;
--		["texture"] = "INV_Axe_19";
--		["notUsable"] = true;
--	},
--	--------------
--	["FOOD"] = {
--		["description"] = AUTOBAR_CLASS_FOOD;
--		["texture"] = "INV_Misc_Food_23";
--		["nonCombat"] = true,
--	},
--	["FOOD_PERCENT"] = {
--		["description"] = AUTOBAR_CLASS_FOOD_PERCENT;
--		["texture"] = "INV_Misc_Food_60",
--		["custom"] = true;
--	},
--	["FOOD_PERCENT_BONUS"] = {
--		["description"] = AUTOBAR_CLASS_FOOD_PERCENT_BONUS;
--		["texture"] = "INV_Misc_Food_62",
--		["custom"] = true;
--	},
--	["FOOD_PERCENT_COMBO"] = {
--		["description"] = AUTOBAR_CLASS_FOOD_PERCENT_COMBO;
--		["texture"] = "INV_Food_ChristmasFruitCake_01",
--		["custom"] = true;
--	},
--	["FOOD_PET_BREAD"] = {
--		["description"] = AUTOBAR_CLASS_FOOD_PET_BREAD;
--		["texture"] = "INV_Misc_Food_35";
--		["nonCombat"] = true,
--		["targetted"] = "PET";
--		["castSpell"] = BS["Feed Pet"];
--	},
--	["FOOD_PET_CHEESE"] = {
--		["description"] = AUTOBAR_CLASS_FOOD_PET_CHEESE;
--		["texture"] = "INV_Misc_Food_37";
--		["nonCombat"] = true,
--		["targetted"] = "PET";
--		["castSpell"] = BS["Feed Pet"];
--	},
--	["FOOD_PET_FISH"] = {
--		["description"] = AUTOBAR_CLASS_FOOD_PET_FISH;
--		["texture"] = "INV_Misc_Fish_22";
--		["nonCombat"] = true,
--		["targetted"] = "PET";
--		["castSpell"] = BS["Feed Pet"];
--	},
--	["FOOD_PET_FRUIT"] = {
--		["description"] = AUTOBAR_CLASS_FOOD_PET_FRUIT;
--		["texture"] = "INV_Misc_Food_19";
--		["nonCombat"] = true,
--		["targetted"] = "PET";
--		["castSpell"] = BS["Feed Pet"];
--	},
--	["FOOD_PET_FUNGUS"] = {
--		["description"] = AUTOBAR_CLASS_FOOD_PET_FUNGUS;
--		["texture"] = "INV_Mushroom_05";
--		["nonCombat"] = true,
--		["targetted"] = "PET";
--		["castSpell"] = BS["Feed Pet"];
--	},
--	["FOOD_PET_MEAT"] = {
--		["description"] = AUTOBAR_CLASS_FOOD_PET_MEAT;
--		["texture"] = "INV_Misc_Food_14";
--		["nonCombat"] = true,
--		["targetted"] = "PET";
--		["castSpell"] = BS["Feed Pet"];
--	},
--	["FOOD_COMBO"] = {
--		["description"] = AUTOBAR_CLASS_FOOD_COMBO;
--		["texture"] = "INV_Misc_Food_33";
--		["nonCombat"] = true,
--	},
--	["FOOD_CONJURED"] = {
--		["description"] = AUTOBAR_CLASS_FOOD_CONJURED;
--		["texture"] = "INV_Misc_Food_73CinnamonRoll";
--		["nonCombat"] = true,
--		["castList"] = {"MAGE", BS["Conjure Food"],},
--	},
--	["FOOD_CONJURE"] = {
--		["description"] = AUTOBAR_CLASS_FOOD_CONJURE,
--		["texture"] = BS:GetShortSpellIcon("Conjure Food"),
--		["spell"] = true,
--	},
--	["FOOD_BUFF"] = {
--		["description"] = L["FOOD_BUFF"];
--		["texture"] = "INV_Misc_Food_47";
--		["nonCombat"] = true,
--	},
--	["FOOD_AGILITY"] = {
--		["description"] = L["FOOD_AGILITY"];
--		["texture"] = "INV_Misc_Fish_13";
--		["nonCombat"] = true,
--	},
--	["FOOD_ATTACK_POWER"] = {
--		["description"] = L["FOOD_ATTACK_POWER"];
--		["texture"] = "INV_Misc_Fish_13";
--		["nonCombat"] = true,
--	},
--	["FOOD_HEALING"] = {
--		["description"] = L["FOOD_HEALING"];
--		["texture"] = "INV_Misc_Fish_13";
--		["nonCombat"] = true,
--	},
--	["FOOD_HPREGEN"] = {
--		["description"] = L["FOOD_HPREGEN"];
--		["texture"] = "INV_Misc_Fish_19";
--		["nonCombat"] = true,
--	},
--	["FOOD_INTELLECT"] = {
--		["description"] = L["FOOD_INTELLECT"];
--		["texture"] = "INV_Misc_Food_63";
--		["nonCombat"] = true,
--	},
--	["FOOD_MANAREGEN"] = {
--		["description"] = L["FOOD_MANAREGEN"];
--		["texture"] = "INV_Drink_17";
--		["nonCombat"] = true,
--	},
--	["FOOD_SPELL_DAMAGE"] = {
--		["description"] = L["FOOD_SPELL_DAMAGE"];
--		["texture"] = "INV_Misc_Food_65";
--		["nonCombat"] = true,
--	},
--	["FOOD_SPIRIT"] = {
--		["description"] = L["FOOD_SPIRIT"];
--		["texture"] = "INV_Misc_Fish_03";
--		["nonCombat"] = true,
--	},
--	["FOOD_STAMINA"] = {
--		["description"] = L["FOOD_STAMINA"];
--		["texture"] = "INV_Misc_Food_65";
--		["nonCombat"] = true,
--	},
--	["FOOD_STRENGTH"] = {
--		["description"] = L["FOOD_STRENGTH"];
--		["texture"] = "INV_Misc_Food_41";
--		["nonCombat"] = true,
--	},
--	["FOOD_OTHER"] = {
--		["description"] = L["FOOD_OTHER"];
--		["texture"] = "INV_Drink_17";
--		["nonCombat"] = true,
--	},
--	["FOOD_ARATHI"] = {
--		["description"] = AUTOBAR_CLASS_FOOD_ARATHI;
--		["texture"] = "INV_Misc_Food_33";
--		["nonCombat"] = true,
--		["location"] = AUTOBAR_ARATHIBASIN;
--	},
--	["FOOD_WARSONG"] = {
--		["description"] = AUTOBAR_CLASS_FOOD_WARSONG;
--		["texture"] = "INV_Misc_Food_33";
--		["nonCombat"] = true,
--		["location"] = AUTOBAR_WARSONGGULCH;
--	},
--	--------------
--	--------------
--	--------------
--	["EXPLOSIVES"] = {
--		["description"] = AUTOBAR_CLASS_EXPLOSIVES;
--		["texture"] = "INV_Misc_Bomb_08";
--		["noselfcast"] = true;	--TODO: add this
--		["targetted"] = true;
--	},
--	--------------
--	["MOUNTS_SUMMONED"] = {
--		["description"] = AUTOBAR_CLASS_MOUNTS_SUMMONED;
--		["texture"] = "Ability_Mount_JungleTiger";
--		["nonCombat"] = true,
--		["arrangeOnUse"] = true,
--		["spell"] = true,
--		["castList"] = {"PALADIN", BS["Summon Warhorse"], "PALADIN", BS["Summon Charger"], "WARLOCK", BS["Summon Felsteed"], "WARLOCK", BS["Summon Dreadsteed"], "DRUID", BS["Travel Form"], "DRUID", BS["Flight Form"], "DRUID", BS["Swift Flight Form"], "SHAMAN", BS["Ghost Wolf"],},
--	},
--	--------------
--};

-- /dump AutoBar_Category_Info["MOUNTS_SUMMONED"]
